@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 12110 2020-04-23 13:27:25Z Trista $
+# $Id: Util.py 12120 2020-04-25 14:13:38Z Trista $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $ (last)
-# $Date: 2020-04-23 21:27:25 +0800 (週四, 23 四月 2020) $
-# $Revision: 12110 $
+# $Date: 2020-04-25 22:13:38 +0800 (週六, 25 四月 2020) $
+# $Revision: 12120 $
 """
 Utilities.
 """
@@ -30,7 +30,7 @@ def update(settingsDict, defaults, config=None):
         if k not in settingsDict:
             settingsDict[k] = v
             
-def determinePrintDetail(printDetail, args)
+def determinePrintDetail(printDetail, args):
     if len(args) >= 2:
         if (args[0].endswith('manage.py')) and (args[1] == 'runserver'):
             printDetail = printDetail
